Struct TrySendError

struct TrySendError<T> { ... }

An error when calling try_send_request.

There is a possibility of an error occurring on a connection in-between the time that a request is queued and when it is actually written to the IO transport. If that happens, it is safe to return the request back to the caller, as it was never fully sent.

Implementations

impl<T> TrySendError<T>

fn take_message(self: &mut Self) -> Option<T>

Take the message from this error.

The message will not always have been recovered. If an error occurs after the message has been serialized onto the connection, it will not be available here.

fn into_error(self: Self) -> Error

Consumes this to return the inner error.

impl<T> Any for TrySendError<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TrySendError<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TrySendError<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Freeze for TrySendError<T>

impl<T> From for TrySendError<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for TrySendError<T>

impl<T> RefUnwindSafe for TrySendError<T>

impl<T> Send for TrySendError<T>

impl<T> Sync for TrySendError<T>

impl<T> Unpin for TrySendError<T>

impl<T> UnsafeUnpin for TrySendError<T>

impl<T> UnwindSafe for TrySendError<T>

impl<T> WithSubscriber for TrySendError<T>

impl<T, U> Into for TrySendError<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TrySendError<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TrySendError<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::fmt::Debug> Debug for TrySendError<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result