#[unsafe(no_mangle)]pub extern "C" fn hyper_body_new() -> *mut hyper_bodyAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Creates a new “empty” body.
If not configured, this body acts as an empty payload.
To avoid a memory leak, the body must eventually be consumed by
hyper_body_free, hyper_body_foreach, or hyper_request_set_body.