#[unsafe(no_mangle)]pub extern "C" fn hyper_executor_free(exec: *const hyper_executor)Available on crate feature
ffi and hyper_unstable_ffi only.Expand description
Frees an executor and any incomplete tasks still part of it.
This should be used for any executor once it is no longer needed.