#[unsafe(no_mangle)]pub extern "C" fn hyper_executor_poll(
exec: *const hyper_executor,
) -> *mut hyper_taskAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Polls the executor, trying to make progress on any tasks that can do so.
If any task from the executor is ready, returns one of them. The way tasks signal being finished is internal to Hyper. The order in which tasks are returned is not guaranteed. Use userdata to distinguish between tasks.
To avoid a memory leak, the task must eventually be consumed by
hyper_task_free.
If there are no ready tasks, this returns NULL.