#[unsafe(no_mangle)]pub extern "C" fn hyper_executor_push(
exec: *const hyper_executor,
task: *mut hyper_task,
) -> hyper_codeAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Push a task onto the executor.
The executor takes ownership of the task, which must not be accessed again.
Ownership of the task will eventually be returned to the user from
hyper_executor_poll.
To distinguish multiple tasks running on the same executor, use hyper_task_set_userdata.