#[unsafe(no_mangle)]pub extern "C" fn hyper_headers_foreach(
headers: *const hyper_headers,
func: extern "C" fn(*mut c_void, *const u8, usize, *const u8, usize) -> c_int,
userdata: *mut c_void,
)Available on crate feature
ffi and hyper_unstable_ffi only.Expand description
Iterates the headers passing each name and value pair to the callback.
The userdata pointer is also passed to the callback.
The callback should return HYPER_ITER_CONTINUE to keep iterating, or
HYPER_ITER_BREAK to stop.