hyper_request_set_uri_parts

Function hyper_request_set_uri_parts 

#[unsafe(no_mangle)]
pub extern "C" fn hyper_request_set_uri_parts( req: *mut hyper_request, scheme: *const u8, scheme_len: usize, authority: *const u8, authority_len: usize, path_and_query: *const u8, path_and_query_len: usize, ) -> hyper_code
Available on crate feature ffi and hyper_unstable_ffi only.
Set the URI of the request with separate scheme, authority, and path/query strings.

Each of scheme, authority, and path_and_query should either be null, to skip providing a component, or point to a UTF-8 encoded string. If any string pointer argument is non-null, its corresponding len parameter must be set to the string’s length.