#[unsafe(no_mangle)]pub extern "C" fn hyper_response_body(
resp: *mut hyper_response,
) -> *mut hyper_bodyAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Take ownership of the body of this response.
It is safe to free the response even after taking ownership of its body.
To avoid a memory leak, the body must eventually be consumed by
hyper_body_free, hyper_body_foreach, or hyper_request_set_body.