#[no_mangle]
pub extern "C" fn hyper_response_reason_phrase(
resp: *const hyper_response,
) -> *const u8Available on crate feature
ffi and hyper_unstable_ffi only.Expand description
Get a pointer to the reason-phrase of this response.
This buffer is not null-terminated.
This buffer is owned by the response, and should not be used after the response has been freed.
Use hyper_response_reason_phrase_len() to get the length of this
buffer.