#[unsafe(no_mangle)]pub extern "C" fn hyper_task_value(
task: *mut hyper_task,
) -> *mut c_voidAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Takes the output value of this task.
This must only be called once polling the task on an executor has finished this task.
Use hyper_task_type to determine the type of the void * return value.
To avoid a memory leak, a non-empty return value must eventually be
consumed by a function appropriate for its type, one of
hyper_error_free, hyper_clientconn_free, hyper_response_free, or
hyper_buf_free.