hyper_waker_wake

Function hyper_waker_wake 

#[unsafe(no_mangle)]
pub extern "C" fn hyper_waker_wake(waker: *mut hyper_waker)
Available on crate feature ffi and hyper_unstable_ffi only.
Wake up the task associated with a waker.

This does not do work towards associated task. Instead, it signals to the task’s executor that the task is ready to make progress. The application is responsible for calling hyper_executor_poll, which will in turn do work on all tasks that are ready to make progress.

NOTE: This consumes the waker. You should not use or free the waker afterwards.