Trait Http2ServerConnExec

trait Http2ServerConnExec<F, B: Body>: sealed::Sealed<(F, B)> + Clone

An executor to spawn http2 connections.

This trait is implemented for any type that implements Executor trait for any future.

This trait is sealed and cannot be implemented for types outside this crate.