Struct hyper::rt::ReadBufCursor

source ·
pub struct ReadBufCursor<'a> { /* private fields */ }
The cursor part of a ReadBuf.

This is created by calling ReadBuf::unfilled().

Implementations

source

impl<'data> ReadBufCursor<'data>

source

pub unsafe fn as_mut(&mut self) -> &mut [MaybeUninit<u8>]

Access the unfilled part of the buffer.

Safety

The caller must not uninitialize any bytes that may have been initialized before.

source

pub unsafe fn advance(&mut self, n: usize)

Advance the filled cursor by n bytes.

Safety

The caller must take care that n more bytes have been initialized.