Struct hyper::server::conn::Parts [−][src]
pub struct Parts<T, S> {
pub io: T,
pub read_buf: Bytes,
pub service: S,
// some fields omitted
}Expand description
Deconstructed parts of a Connection.
This allows taking apart a Connection at a later time, in order to
reclaim the IO object, and additional related pieces.
Fields
io: TThe original IO object used in the handshake.
read_buf: BytesA buffer of bytes that have been read but not processed as HTTP.
If the client sent additional bytes after its last request, and this connection “ended” with an upgrade, the read buffer will contain those bytes.
You will want to check for any existing bytes if you plan to continue communicating on the IO object.
service: SThe Service used to serve this connection.