Type Alias Result
type Result = Result<T, Error>
Result type often returned from methods that can have hyper Errors.
Resulttype Result = Result<T, Error>
Result type often returned from methods that can have hyper Errors.