Struct Incoming
struct Incoming { ... }
A stream of Bytes, used when receiving bodies from the network.
Note that Users should not instantiate this struct directly. When working with the hyper client,
Incoming is returned to you in responses. Similarly, when operating with the hyper server,
it is provided within requests.
Examples
async
Implementations
impl Body for Incoming
fn poll_frame(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Result<Frame<<Self as >::Data>, <Self as >::Error>>>fn is_end_stream(self: &Self) -> boolfn size_hint(self: &Self) -> SizeHint
impl Debug for Incoming
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Incoming
impl RefUnwindSafe for Incoming
impl Send for Incoming
impl Sync for Incoming
impl Unpin for Incoming
impl UnsafeUnpin for Incoming
impl UnwindSafe for Incoming
impl<T> Any for Incoming
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Incoming
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Incoming
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Incoming
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for Incoming
impl<T> WithSubscriber for Incoming
impl<T, U> Into for Incoming
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Incoming
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Incoming
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>