pub struct Error { /* private fields */ }Expand description
Represents errors that can occur handling HTTP streams.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_parse_too_large(&self) -> bool
pub fn is_parse_too_large(&self) -> bool
Returns true if this was an HTTP parse error caused by a message that was too large.
Sourcepub fn is_parse_status(&self) -> bool
pub fn is_parse_status(&self) -> bool
Returns true if this was an HTTP parse error caused by an invalid response status code or reason phrase.
Sourcepub fn is_canceled(&self) -> bool
pub fn is_canceled(&self) -> bool
Returns true if this was about a Request that was canceled.
Sourcepub fn is_connect(&self) -> bool
pub fn is_connect(&self) -> bool
Returns true if this was an error from Connect.
Sourcepub fn is_incomplete_message(&self) -> bool
pub fn is_incomplete_message(&self) -> bool
Returns true if the connection closed before a message could complete.
Sourcepub fn is_body_write_aborted(&self) -> bool
pub fn is_body_write_aborted(&self) -> bool
Returns true if the body write was aborted.
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if the error was caused by a timeout.